==> scraping-1.1.31-sources.jar: com/tenqube/visual_scraper/scrap/login/ApiLogin.java <==
package com.tenqube.visual_scraper.scrap.login;

import android.support.annotation.NonNull;

import com.tenqube.visual_scraper.db.entity.LoginApiRule;

import static com.tenqube.visual_scraper.utils.LogUtil.makeLogTag;

/**
 * Created by tenqube on 2018. 5. 18..cw.jeon
 */

public class ApiLogin implements LoginService {
//    private ParsingRuleData mParsingRuleData;
    private LoginApiRule loginApiRule;
    private static final String TAG = makeLogTag(ApiLogin.class);

    public ApiLogin(LoginApiRule loginApiRule) {
        this.loginApiRule = loginApiRule;
//        mParsingRuleData = parsingRuleData;
    }
    /**
     * loginParams setting
     * 로그인 post params setting
     */
    @Override
    public void login(@NonNull OnLoginCallback callback) {

        try {
//            Connection.Response response = Jsoup.connect(loginApiRule.getUrl())
//                    .userAgent(USER_AGENT)
//                    .followRedirects(true)
//                    .timeout(6000)
//                    .ignoreContentType(true)
//                    .data(loginApiRule.getLoginParams())
//                    .method(Connection.Method.POST)
//                    .execute();

//            Map<String, String> cookies = response.cookies();

//            if (isValidCookie(cookies)) {

//                String cookie = Validator.convertMaptoString(response.cookies());
//                callback.onLoginSuccess(cookie);

//            } else {
//                callback.onLoginFail(response.statusCode(), Constants.MESSAGES.INVALID_USER_INFO);
//            }
        } catch (Exception e) {
            e.printStackTrace();
            callback.onLoginFail(0, e.toString());
        }
    }

//    private boolean isValidCookie(Map<String, String> cookies) {
//        if(mParsingRuleData.getValidCookieKey() != null) {
//            for (String invalidKey : mParsingRuleData.getValidCookieKey()){
//
//                if (!cookies.containsKey(invalidKey))
//                    return false;
//            }
//        }
//
//        return true;
//    }


}

==> scraping-1.3.18-sources.jar: com/tenqube/visual_scraper/scrap/login/ApiLogin.java <==
package com.tenqube.visual_scraper.scrap.login;

import android.support.annotation.NonNull;

import com.tenqube.visual_scraper.db.entity.LoginApiRule;

import static com.tenqube.visual_scraper.utils.LogUtil.makeLogTag;

/**
 * Created by tenqube on 2018. 5. 18..cw.jeon
 */

public class ApiLogin implements LoginService {
//    private ParsingRuleData mParsingRuleData;
    private LoginApiRule loginApiRule;
    private static final String TAG = makeLogTag(ApiLogin.class);

    public ApiLogin(LoginApiRule loginApiRule) {
        this.loginApiRule = loginApiRule;
//        mParsingRuleData = parsingRuleData;
    }
    /**
     * loginParams setting
     * 로그인 post params setting
     */
    @Override
    public void login(@NonNull OnLoginCallback callback) {

        try {
//            Connection.Response response = Jsoup.connect(loginApiRule.getUrl())
//                    .userAgent(USER_AGENT_NORMAL)
//                    .followRedirects(true)
//                    .timeout(6000)
//                    .ignoreContentType(true)
//                    .data(loginApiRule.getLoginParams())
//                    .method(Connection.Method.POST)
//                    .execute();

//            Map<String, String> cookies = response.cookies();

//            if (isValidCookie(cookies)) {

//                String cookie = Validator.convertMaptoString(response.cookies());
//                callback.onLoginSuccess(cookie);

//            } else {
//                callback.onLoginFail(response.statusCode(), Constants.MESSAGES.INVALID_USER_INFO);
//            }
        } catch (Exception e) {
            e.printStackTrace();
            callback.onLoginFail(0, e.toString());
        }
    }

//    private boolean isValidCookie(Map<String, String> cookies) {
//        if(mParsingRuleData.getValidCookieKey() != null) {
//            for (String invalidKey : mParsingRuleData.getValidCookieKey()){
//
//                if (!cookies.containsKey(invalidKey))
//                    return false;
//            }
//        }
//
//        return true;
//    }


}
